<?php

namespace App\Http\Controllers;

use App\Models\User;
use App\Models\Application;
use Illuminate\Support\Str;
use Illuminate\Http\Request;
use App\Models\WorkExperience;
use Barryvdh\DomPDF\Facade\Pdf;
use App\Models\ApplicationCareer;

use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use App\Models\ApplicationCareerStatus;

class ApplicationController extends Controller
{
    public function index()
    {
        $application = Application::orderBy('id', 'DESC')->get();

        return view('backend.modules.application.index', compact('application'));
    }
    public function edit($id)
    {
        $application = Application::with(['workExperiences', 'career'])->findOrFail($id);

        return view('backend.modules.application.edit', compact('application'));
    }
    public function show($id)
    {
        $application = Application::with(['workExperiences', 'career'])->findOrFail($id);

        return view('backend.modules.application.show', compact('application'));
    }
    public function storeStep1(Request $request)
    {
        // Validate step 1 data
        $validatedData = $request->validate([
            'first_name' => 'required|string|max:255',
            'last_name' => 'required|string|max:255',
            'middle_name' => 'nullable|string|max:255',
            'suffix' => 'nullable|string|max:255',
            'sex' => 'required|string|max:255',
            'religion' => 'required|string|max:255',
            'birth_date' => 'required|string|max:255',
            'birth_place' => 'required|string|max:255',
            'email' => 'required|email|max:255',
            'phone_no' => 'required|string|max:15',
            'home_address' => 'required|string|max:255',
            'city' => 'required|string|max:255',
            'province' => 'required|string|max:255',
            'region' => 'required|string|max:255',
        ]);

        // Store step 1 data in the session
        session(['application' => array_merge(session('application', []), $validatedData)]);

        // Redirect to step 2
        return redirect()->route('application.step2');
    }

    public function storeStep2(Request $request)
    {
        // Validate step 2 data
        $validatedData = $request->validate([
            'education' => 'nullable|string|max:255',
            'degree' => 'nullable|string|max:255',
            'tesda' => 'nullable|string|max:255',
            'work_experience' => 'nullable|array',
            'work_experience.*.company_name' => 'nullable|string|max:255',
            'work_experience.*.job_title' => 'nullable|string|max:255',
            'work_experience.*.start_date' => 'nullable|string|max:255', // Changed from start_date to start_month
            'work_experience.*.start_year' => 'nullable|string|max:255',  // Added validation for start_year
            'work_experience.*.end_date' => 'nullable|string|max:255',   // Changed from end_date to end_month
            'work_experience.*.end_year' => 'nullable|string|max:255',     // Added validation for end_year
        ]);

        // Store step 2 data in the session
        session(['application' => array_merge(session('application', []), $validatedData)]);

        // Redirect to step 3
        return redirect()->route('application.step3');
    }

    public function storeStep3(Request $request)
    {
        // Validate step 3 data
        $validatedData = $request->validate([
            'employment_status' => 'nullable|string',
            'question_1' => 'nullable|string',
            'question_2' => 'nullable|string',
            'question_3' => 'nullable|string',
        ]);

        // Merge all steps' data and save application
        $applicationData = array_merge(session('application', []), $validatedData);
        // Retrieve email from session
        $email = session('application.email');
        $first_name = session('application.first_name');


        if ($email) {
            // Generate a random 3-character string
            $randomString = Str::random(3);

            // Create a temporary password combining first_name and the random string
            $temporaryPassword = $first_name . "_" . $randomString;

            // Create a new user with the email and the hashed temporary password
            $user = User::create([
                'email' => $email,
                'password' => Hash::make($temporaryPassword), // Hash the temporary password
                'name' => $first_name, // Optional: store the first name if available
                'role' => 'user'
            ]);

            // Get the user ID
            $user_id = $user->id;

            // Optionally, send an email to the user with the temporary password
            // Mail::to($email)->send(new TemporaryPasswordMail($temporaryPassword));
        }

        $applicationData['user_id'] = $user_id;
        // Save application to the database
        $application = Application::create($applicationData);

        if (!empty(session('application.work_experience'))) {
            foreach (session('application.work_experience') as $experience) {
                WorkExperience::create([
                    'application_id' => $application->id, // Link to the newly created application
                    'company_name' => $experience['company_name'] ?? null,
                    'job_title' => $experience['job_title'] ?? null,
                    // Combine start_month and start_year into start_date, default to null if empty
                    'start_date' => !empty($experience['start_date']) && !empty($experience['start_year'])
                        ? $experience['start_date'] . ' ' . $experience['start_year']
                        : null,
                    // Combine end_month and end_year into end_date, default to null if empty
                    'end_date' => !empty($experience['end_date']) && !empty($experience['end_year'])
                        ? $experience['end_date'] . ' ' . $experience['end_year']
                        : null,
                ]);
            }
        }



        if (session()->has('applications.career_ids')) {
            $careerIds = session('applications.career_ids');

            // Attach the career_ids to the application
            $application->careers()->attach($careerIds);

            // Optionally, you can clear the session career_ids after attaching
            session()->forget('applications.career_ids');
        }

        // Clear session data
        session()->forget('application');
        session(['email' => $email, 'temporaryPassword' => $temporaryPassword]);

        // Redirect to success page
        return redirect()->route('careers');
    }

    public function destroy($id)
    {
        $application = Application::findOrFail($id);
        $application->delete();

        return redirect()->route('applications.index');
    }

    public function saveApplication(Request $request)
    {
        // Check if user is logged in
        if (Auth::check()) {
            // Retrieve the logged-in user
            $user = Auth::user();

            // Retrieve or create an application for the user
            $application = Application::firstOrCreate([
                'user_id' => $user->id
            ]);

            // Check if the career_id already exists in the pivot table
            if ($application->careers()->where('career_id', $request->career_id)->exists()) {
                return redirect()->back()->with('warning', 'You have already applied for this career.');
            }

            // Save the career_id and application_id in the pivot table without duplicating
            $application->careers()->syncWithoutDetaching($request->career_id);

            return redirect()->back()->with('success', 'Application submitted successfully.')->with('success1', 'Application Form');
        } else {
            $career_id = $request->career_id;

            // Replace the existing career_id in the session
            session(['applications.career_ids' => [$career_id]]);

            return redirect('application-form')->with('message', 'Please fill out the form.');
        }
    }

    public function updateStatus(Request $request, $applicationCareerId)
    {
        $request->validate([
            'status' => 'required|string|max:255',
            'remarks' => 'nullable|string|max:500',
        ]);
        $recruiterId = auth()->user()->id;
        // Save new status entry
        ApplicationCareerStatus::create([
            'application_career_id' => $applicationCareerId,
            'status' => $request->status,
            'remarks' => $request->remarks,
            'recruiter_id' => $recruiterId,
        ]);

        return redirect()->back()->with('success', 'Status updated successfully.');
    }

    public function downloadPDF($id)
    {
        $application = Application::with('workExperiences')->findOrFail($id);

        // Render the Blade view into HTML
        $pdf = Pdf::loadView('backend.application.print', compact('application'));

        // Download the generated PDF
        return $pdf->download('application-details.pdf');
    }

    public function update(Request $request, $id)
    {
        // Validate the request data
        $request->validate([
            'first_name' => 'required|string',
            'last_name' => 'required|string',
            'email' => 'required|email',
            // Add other validation rules as needed
        ]);

        $application = Application::findOrFail($id);

        // Update the main application fields
        $application->update($request->except('work_experiences'));

        // Handle work experiences
        foreach ($request->work_experiences as $experience) {
            if (isset($experience['id']) && $experience['id']) {
                // Update existing work experience
                $workExperience = WorkExperience::find($experience['id']);
                if ($workExperience) {
                    $workExperience->update([
                        'company_name' => $experience['company_name'],
                        'job_title' => $experience['job_title'],
                        'start_date' => $experience['start_date'],
                        'end_date' => $experience['end_date'],
                    ]);
                }
            } else {
                // Create new work experience if no ID is provided
                WorkExperience::create([
                    'application_id' => $application->id,
                    'company_name' => $experience['company_name'],
                    'job_title' => $experience['job_title'],
                    'start_date' => $experience['start_date'],
                    'end_date' => $experience['end_date'],
                ]);
            }
        }

        return redirect()->route('applications.show', $id)->with('success', 'Application updated successfully.');
    }





    public function store(Request $request)
    {
        // Validate step 1 data
        $validatedData = $request->validate([
            'first_name' => 'required|string|max:255',
            'last_name' => 'required|string|max:255',
            'middle_name' => 'nullable|string|max:255',
            'suffix' => 'nullable|string|max:255',
            'sex' => 'required|string|max:255',
            'religion' => 'required|string|max:255',
            'birth_date' => 'required|string|max:255',
            'birth_place' => 'required|string|max:255',
            'email' => 'required|email|max:255',
            'phone_no' => 'required|string|max:15',
            'home_address' => 'required|string|max:255',
            'city' => 'required|string|max:255',
            'province' => 'required|string|max:255',
            'region' => 'required|string|max:255',
            'education' => 'nullable|string|max:255',
            'degree' => 'nullable|string|max:255',
            'tesda' => 'nullable|string|max:255',
            'work_experience' => 'nullable|array',
            'work_experience.*.company_name' => 'nullable|string|max:255',
            'work_experience.*.job_title' => 'nullable|string|max:255',
            'work_experience.*.start_date' => 'nullable|string|max:255', // Changed from start_date to start_month
            'work_experience.*.start_year' => 'nullable|string|max:255',  // Added validation for start_year
            'work_experience.*.end_date' => 'nullable|string|max:255',   // Changed from end_date to end_month
            'work_experience.*.end_year' => 'nullable|string|max:255',     // Added validation for end_year
            'employment_status' => 'nullable|string',
            'question_1' => 'nullable|string',
            'question_2' => 'nullable|string',
            'question_3' => 'nullable|string',
        ]);



        $application = Application::create($validatedData);

        if (!empty(session('application.work_experience'))) {
            foreach (session('application.work_experience') as $experience) {
                WorkExperience::create([
                    'application_id' => $application->id, // Link to the newly created application
                    'company_name' => $experience['company_name'] ?? null,
                    'job_title' => $experience['job_title'] ?? null,
                    // Combine start_month and start_year into start_date, default to null if empty
                    'start_date' => !empty($experience['start_date']) && !empty($experience['start_year'])
                        ? $experience['start_date'] . ' ' . $experience['start_year']
                        : null,
                    // Combine end_month and end_year into end_date, default to null if empty
                    'end_date' => !empty($experience['end_date']) && !empty($experience['end_year'])
                        ? $experience['end_date'] . ' ' . $experience['end_year']
                        : null,
                ]);
            }
        }


        return redirect()->back();
    }
}
