<?php

namespace App\Http\Controllers\Frontend;

use App\Models\Banner;
use App\Models\Career;
use App\Models\Category;
use App\Models\Services;
use App\Models\Application;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use App\Http\Controllers\Controller;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;

class PageController extends Controller
{

    public function home(Request $request)
    {
        $services = Services::all();

        return view('frontend.pages.home', compact('services'));
    }
    public function careers()
    {
        $careers = Career::all();

        // Optional: Retrieve email and temporary password from session (if available)
        $email = session('email');
        $temporaryPassword = session('temporaryPassword');

        $banner = Banner::all();

        $services = Services::all();
        // Clear the session values after retrieving them
        session()->forget(['email', 'temporaryPassword']);

        return view('frontend.pages.careers', compact('careers', 'email', 'temporaryPassword', 'banner', 'services'));
    }

    public function search(Request $request)
    {
        // Check if all search fields are empty
        if (!$request->filled('search') && !$request->filled('category') && !$request->filled('location')) {
            // Redirect to the careers route if no search filters are applied
            return redirect()->route('careers');
        }

        // Create a query builder for Career with the category relationship
        $query = Career::with('category');

        // Filter by job title or keyword
        if ($request->filled('search')) {
            $query->where('jobtitle', 'like', '%' . $request->input('search') . '%');
        }

        // Filter by category (assuming you want to search by the category name)
        if ($request->filled('category')) {
            $query->whereHas('category', function ($q) use ($request) {
                $q->where('category_name', 'like', '%' . $request->input('category') . '%');
            });
        }

        // Filter by location
        if ($request->filled('location')) {
            $query->where('location', 'like', '%' . $request->input('location') . '%');
        }

        // Execute the query and get the results
        $careers = $query->get();

        // Optional: Retrieve email and temporary password from session (if available)
        $email = session('email');
        $temporaryPassword = session('temporaryPassword');

        $banner = Banner::all();

        // Clear the session values after retrieving them
        session()->forget(['email', 'temporaryPassword']);
        $services = Services::all();
        // Return the view with the search results
        return view('frontend.pages.careers', compact('careers', 'email', 'temporaryPassword', 'banner', 'services'));
    }


    public function applicationForm(Request $request)
    {
        $services = Services::all();
        return view('frontend.pages.application-form', compact('services'));
    }
    public function applicationForm2(Request $request)
    {
        $services = Services::all();
        return view('frontend.pages.application-form-2', compact('services'));
    }
    public function applicationForm3(Request $request)
    {
        $services = Services::all();
        return view('frontend.pages.application-form-3', compact('services'));
    }
    public function careerSearch($id, Request $request)
    {


        // Fetch the specific career based on the ID
        $career = Career::with(['responsibilities', 'requirements', 'levels', 'yearsOfExperience', 'specializations', 'qualifications'])->findOrFail($id);

        // Fetch the banner
        $banner = Banner::all();

        // Initialize the query builder for all careers (for search and filtering)
        $query = Career::with('category');

        // Apply filters based on request input
        if ($request->filled('search')) {
            $query->where('jobtitle', 'like', '%' . $request->search . '%')
                ->orWhere('subtitle', 'like', '%' . $request->search . '%');
        }

        if ($request->filled('category')) {
            $query->whereHas('category', function ($q) use ($request) {
                $q->where('category_name', 'like', '%' . $request->input('category') . '%');
            });
        }

        if ($request->filled('location')) {
            $query->where('location', 'like', '%' . $request->location . '%');
        }

        if ($request->filled('dateposted')) {
            if ($request->dateposted == 'This Week') {
                $query->where('created_at', '>=', now()->subWeek());
            } elseif ($request->dateposted == 'This Month') {
                $query->where('created_at', '>=', now()->subMonth());
            }
        }

        if ($request->filled('rate')) {
            $query->where('rate', '>=', str_replace('₱', '', $request->rate));
        }

        if ($request->filled('work_schedule')) {
            $query->where('work_schedule', '=', $request->work_schedule);
        }

        if ($request->filled('job_type')) {
            $query->where('job_type', '=', $request->job_type);
        }

        // Get paginated filtered careers
        $allcareers = $query->paginate(3);

        // Get categories for the select input
        $categories = Category::all();

        $services = Services::all();

        return view('frontend.pages.career-search', compact('career', 'categories', 'allcareers', 'banner', 'services'));
    }
    public function about(Request $request)
    {
        $services = Services::all();

        return view('frontend.pages.about', compact('services'));
    }

    public function services()
    {

        $services = Services::all();

        return view('frontend.pages.services', compact('services'));
    }

    public function services_details($id)
    {

        $servicesdetails = Services::findOrFail($id);

        $services = Services::all();
        return view('frontend.pages.services_details', compact('servicesdetails', 'services'));
    }


    public function janitorial(Request $request)
    {
        return view('frontend.pages.janitorial');
    }
    public function outsourcing(Request $request)
    {
        return view('frontend.pages.outsourcing');
    }
    public function manufacturing(Request $request)
    {
        return view('frontend.pages.manufacturing');
    }
    public function contact(Request $request)
    {
        $services = Services::all();
        return view('frontend.pages.contact',   compact('services'));
    }
    public function login(Request $request)
    {
        $services = Services::all();
        return view('frontend.pages.login', compact('services'));
    }



    public function user_change_password(Request $request)
    {
        $services = Services::all();
        return view('frontend.pages.user-change-password', compact('services'));
    }

    public function changePassword(Request $request)
    {
        // Validate the input
        $request->validate([
            'email' => 'required|email',
            'current_password' => 'required',
            'new_password' => 'required', // Ensure you have a confirmation field
        ]);

        // Check if the email matches the logged-in user
        $user = Auth::user();
        if ($user->email !== $request->email) {
            return back()->withErrors(['email' => 'The provided email does not match your account.']);
        }

        // Check if the current password is correct
        if (!Hash::check($request->current_password, $user->password)) {
            return back()->withErrors(['current_password' => 'The provided current password is incorrect.']);
        }

        // Update the password
        $user->password = Hash::make($request->new_password);
        $user->save();

        return back()->with('success', 'Password changed successfully.');
    }
    public function recruiter_dashboard(Request $request)
    {
        $careers = Career::with('applications') // Assuming you have a relationship set up for applications
            ->orderBy('id', 'DESC')
            ->get();

        $services = Services::all();
        return view('frontend.pages.recruiter-dashboard', compact('careers', 'services'));
    }
    public function Applicants($id)
    {
        $career = Career::with('applications')->findOrFail($id);

        // Collect pivot IDs that should not be displayed
        $excludedPivotIds = DB::table('application_career_status')
            ->pluck('application_career_id')
            ->toArray();

        // Filter applicants to exclude those with excluded pivot IDs
        $applicants = $career->applications->filter(function ($application) use ($excludedPivotIds) {
            $pivotId = $application->pivot->id; // Adjust this if your pivot key is named differently
            return !in_array($pivotId, $excludedPivotIds);
        });
        $services = Services::all();
        return view('frontend.pages.recruiter-applicants', compact('career', 'applicants', 'services'));
    }




    public function user_dashboard(Request $request)
    {
        $userId = auth()->user()->id;

        // Retrieve applications with the latest status and remarks for each career the user applied to
        $applications = Application::with(['applicationCareer.career', 'applicationCareer.applicationCareerStatus' => function ($query) {
            $query->latest(); // Ensures the latest status is fetched
        }])
            ->where('user_id', $userId)
            ->get();
        $services = Services::all();
        return view('frontend.pages.user-dashboard', compact('applications', 'services'));
    }

    public function applicants_details($id, $career_id)
    {
        $application = Application::with(['workExperiences', 'career', 'careers', 'applicationCareer.career', 'applicationCareer.applicationCareerStatus'])->findOrFail($id);

        $applicant = $application->careers->firstWhere('id', $career_id);
        $pivotId = null;

        // If the applicant exists, retrieve the pivot ID
        if ($applicant) {
            $pivotId = $applicant->pivot->id;

            // Check if the pivot ID exists in the application_career_status table
            $exists = DB::table('application_career_status')->where('application_career_id', $pivotId)->exists();
        } else {
            $exists = false; // Set exists to false if no applicant found
        }
        $services = Services::all();
        return view('frontend.pages.recruiter-applicants-details', compact('application', 'career_id', 'pivotId', 'exists', 'services'));
    }
}
