<?php

namespace App\Http\Controllers;

use App\Models\User;
use App\Models\Application;
use Illuminate\Http\Request;
use App\Models\WorkExperience;
use Illuminate\Support\Facades\Hash;

class UsersController extends Controller
{
    public function index()
    {
        $user = User::orderBy('id', 'DESC')->get();

        return view('backend.modules.users.index', compact('user'));
    }
    public function create()
    {
        return view('backend.modules.users.create');
    }
    public function store(Request $request)
    {
        // Validate the input data for user creation
        $request->validate([
            'name' => 'required|string',
            'email' => 'required|string',
            'password' => 'required',
            'role' => 'required|string',
            'first_name' => 'nullable|string|max:255',
            'last_name' => 'nullable|string|max:255',
            'middle_name' => 'nullable|string|max:255',
            'suffix' => 'nullable|string|max:255',
            'sex' => 'nullable|string|max:255',
            'religion' => 'nullable|string|max:255',
            'birth_date' => 'nullable|string|max:255',
            'birth_place' => 'nullable|string|max:255',
            'phone_no' => 'nullable|string|max:15',
            'home_address' => 'nullable|string|max:255',
            'city' => 'nullable|string|max:255',
            'province' => 'nullable|string|max:255',
            'region' => 'nullable|string|max:255',
            'education' => 'nullable|string|max:255',
            'degree' => 'nullable|string|max:255',
            'tesda' => 'nullable|string|max:255',
            'work_experience' => 'nullable|array',
            'work_experience.*.company_name' => 'nullable|string|max:255',
            'work_experience.*.job_title' => 'nullable|string|max:255',
            'work_experience.*.start_date' => 'nullable|string|max:255', // Changed from start_date to start_month
            'work_experience.*.start_year' => 'nullable|string|max:255',  // Added validation for start_year
            'work_experience.*.end_date' => 'nullable|string|max:255',   // Changed from end_date to end_month
            'work_experience.*.end_year' => 'nullable|string|max:255',     // Added validation for end_year
            'employment_status' => 'nullable|string',
            'question_1' => 'nullable|string',
            'question_2' => 'nullable|string',
            'question_3' => 'nullable|string',
        ]);
        $user = User::create([
            'name' => $request->input('name'),
            'email' => $request->input('email'),
            'password' => Hash::make($request->input('password')),
            'role' => $request->input('role'),
        ]);

        // Check if the role is 'applicant' and proceed
        if ($request->role === 'applicant') {

            // Prepare the validated data for the application
            $validatedData = $request->except(['work_experience', 'role', 'name', 'password']);
            $validatedData['user_id'] = $user->id; // Link application to the user

            // Create the application record
            $application = Application::create($validatedData);

            // Check if work_experience exists in the session and insert into the WorkExperience table
            if (!empty($request->work_experience)) {
                foreach ($request->work_experience as $experience) {
                    WorkExperience::create([
                        'application_id' => $application->id, // Link to the newly created application
                        'company_name' => $experience['company_name'] ?? null,
                        'job_title' => $experience['job_title'] ?? null,
                        // Combine start_month and start_year into start_date, default to null if empty
                        'start_date' => !empty($experience['start_date']) && !empty($experience['start_year'])
                            ? $experience['start_date'] . ' ' . $experience['start_year']
                            : null,
                        // Combine end_month and end_year into end_date, default to null if empty
                        'end_date' => !empty($experience['end_date']) && !empty($experience['end_year'])
                            ? $experience['end_date'] . ' ' . $experience['end_year']
                            : null,
                    ]);
                }
            }

            // Redirect to a users index or another view
            return redirect()->route('users.index')->with('success', 'User and application created successfully.');
        }

        // If role is not 'applicant', handle accordingly or redirect
        return redirect()->route('users.index');
    }

    public function edit($id)
    {
        $user = User::findOrFail($id);

        return view('backend.modules.users.edit', compact('user'));
    }
    public function update(Request $request, $id)
    {
        $request->validate([
            'name' => 'required|string',
            'email' => 'required|string|email|unique:users,email,' . $id,
            'password' => 'required|string|min:8',
            'role' => 'required|string'
        ]);

        $user = User::findOrFail($id);

        $user->name = $request->input('name');
        $user->email = $request->input('email');

        // Update password only if provided
        if ($request->filled('password')) {
            $user->password = Hash::make($request->input('password'));
        }

        $user->role = $request->input('role');
        $user->save();

        return redirect()->route('users.index')->with('success', 'User updated successfully');
    }

    public function destroy($id)
    {
        $user = User::findOrFail($id);
        $user->delete();

        return redirect()->route('users.index');
    }
}
